#!/usr/bin/perl
=head1 NAME

df - Munin plugin to monitor disk usage

=head1 APPLICABLE SYSTEMS

Every Linux system with df installed.

=head1 AUTHOR

Ingvar Hagelund

=head1 LICENSE

GPLv2

=head1 

Update and adapted to bm-stats beacuse Munin rocks :-)

=cut

use File::Path ;



my $path_to_data_dir = "/var/lib/bm-stats/" ;
my $generalDir       = "general/";
my $dfFile 	     = $path_to_data_dir.$generalDir."myDF.dat";

&control_rep($path_to_data_dir.$generalDir);

my $mktime = time() ;



sub control_rep {
    my $rep = $_[0];
    if(opendir("dir","$rep")) {
       closedir("dir");  
    } else {
       mkpath("$rep");
    };
}



sub clean_fieldname ($) {
    my $name = shift;

    # Replace a sequence of illegal leading chars with a single _
    $name =~ s/^[^A-Za-z_]+/_/;
    # Replace remaining illegals with _
    $name =~ s/[^A-Za-z0-9_]/_/g;

    # "root" is *not* allowed due to a 2.0 bug
    $name = "__root" if $name eq "root";

    return $name;
}



# For these devices use the mount point, the device is useless
my %usemntpt = ( tmpfs => 1, none => 1, udev => 1, simfs => 1 );

my $exclude = $ENV{'exclude'} || 'none unknown rootfs iso9660 squashfs udf romfs ramfs debugfs cgroup_root devtmpfs tmpfs';
my $dfopts  = "-P -l ".join(' -x ',('',split('\s+',$exclude)));

my $mode = ($ARGV[0] or "print");

# Compile REs from env
my @include_re;
if (defined $ENV{include_re}) {
    foreach my $re (split m{\s+}, $ENV{include_re}) {
        push @include_re, qr/$re/;
    }
}
my @exclude_re;
if (defined $ENV{exclude_re}) {
    foreach my $re (split m{\s+}, $ENV{exclude_re}) {
        push @exclude_re, qr/$re/;
    }
}

sub skip {
    my $name = shift;
    my $mountpt = shift;

    foreach my $re (@include_re) {
        return 0 if ($name =~ $re or $mountpt =~ $re);
    }

    foreach my $re (@exclude_re) {
        return 1 if ($name =~ $re or $mountpt =~ $re);
    }

    return 0;
}

# Open $dfFile 
open(DFdat, ">> $dfFile") || die "Error while opening : $!";

# Read from df
open (DF,"df $dfopts 2>/dev/null |") or die "Unable to open pipe from df: $!";
<DF>; # Skip the header
while (<DF>) {
    next if m{//};

    # Parse the output
    my ($name, undef, $used, $avail, undef, $mountpt, undef) = split(/\s+/, $_, 7);

    next if skip($name, $mountpt);

    # Calculate percentage used
    my $ps = 0;
    $ps = ($used / ($used+$avail)) * 100 if $used;

    $name = $mountpt if defined($usemntpt{$name}) && $usemntpt{$name};
    $name = clean_fieldname($name);

    print DFdat "$mktime,$mountpt,$ps\n"; 
}
close DF;
close DFdat; 


my $trash = `php5 /usr/share/bm-stats/scripts/PHP/do_graph/bmDF.php`;
